@@ -10,9 +10,8 @@ use warnings FATAL => 'all';
 
 package [% class_v %]::Root;
 use base 'HTML::Tested';
-use HTML::Tested qw(HTV);
-__PACKAGE__->ht_add_widget(HTV."::Marked", 'first');
-__PACKAGE__->ht_add_widget(HTV."::Form", form => default_value => 'u');
+__PACKAGE__->ht_add_widget(::HTV."::Marked", 'first');
+__PACKAGE__->ht_add_widget(::HTV."::Form", form => default_value => 'u');
 
 package [% class_v %];
 use base qw(Apache::SWIT::HTPage);
