@@ -4,6 +4,7 @@ use warnings FATAL => 'all';
 package Apache::SWIT::Subsystem::Generator;
 use base 'Apache::SWIT::Maker::GeneratorBase';
 use File::Slurp;
+use Apache::SWIT::Maker::Manifest;
 
 sub location_section_prolog {
 	my ($self, $res, $loc, $e) = @_;
@@ -21,7 +22,7 @@ sub location_section_epilogue {
 
 sub dump_page_entry {
 	my ($self, $res, $v) = @_;
-	my $rc = $self->tree->{root_class};
+	my $rc = Apache::SWIT::Maker::Config->instance->root_class;
 	my $tt_file = $v->{entry_points}->{r}->{template};
 	$v->{class} =~ s/^$rc\:://;
 	$v->{file} = read_file($tt_file);
@@ -35,16 +36,17 @@ sub install_page_entry {
 	my $lcm = lc($module);
 	my $tt_file = $v->{entry_points}->{r}->{template} =
 		"templates/$lcm/" . $v->{entry_points}->{r}->{template};
-	$v->{class} = $self->tree->{root_class} ."::$module\::" . $v->{class};
+	my $rc = Apache::SWIT::Maker::Config->instance->root_class;
+	$v->{class} = "$rc\::$module\::" . $v->{class};
 	$v->{do_not_use} = 1;
-	Apache::SWIT::Maker::mani_wf($tt_file, $v->{file});
+	swmani_write_file($tt_file, $v->{file});
 	delete $v->{file};
 	return $v;
 }
 
 sub httpd_conf_start {
 	my ($self, $res) = @_;
-	my $sc = $self->tree->{session_class};
+	my $sc = Apache::SWIT::Maker::Config->instance->session_class;
 	$res =~ s/$sc/T::$sc/g;
 	return $res;
 }
