@@ -14,22 +14,21 @@ use base 'HTML::Tested::ClassDBI';
 
 package [% class_v %];
 use base qw(Apache::SWIT::HTPage);
-use HTML::Tested qw(HTV);
 
 sub ht_root_class { return __PACKAGE__ . '::Root'; }
 
 sub on_inheritance_end {
 	my $class = shift;
 	my $rc = $class->ht_root_class;
-	$rc->ht_add_widget(HTV."::Hidden", 'ht_id', cdbi_bind => 'Primary');
-	$rc->ht_add_widget(HTV."::Submit", 'submit_button'
+	$rc->ht_add_widget(::HTV."::Hidden", 'ht_id', cdbi_bind => 'Primary');
+	$rc->ht_add_widget(::HTV."::Submit", 'submit_button'
 			, default_value => 'Submit');
-	$rc->ht_add_widget(HTV."::Submit", 'delete_button'
+	$rc->ht_add_widget(::HTV."::Submit", 'delete_button'
 			, default_value => 'Delete');
 	[% FOREACH fields_v %]
-	$rc->ht_add_widget(HTV."::EditBox"
+	$rc->ht_add_widget(::HTV."::EditBox"
 			, [% field %] => cdbi_bind => '');[% END %]
-	$rc->ht_add_widget(HTV."::Form", form => default_value => 'u');
+	$rc->ht_add_widget(::HTV."::Form", form => default_value => 'u');
 	$rc->bind_to_class_dbi($class->main_subsystem_class
 			->[% db_class_v %]);
 }
